@@ -1,6 +1,6 @@
 /* delay.c - Simplistic AAL5-level software delay line */
 
-/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1996-2000 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 /*
@@ -100,12 +100,13 @@ static void loop(void)
 	    for (lnk = links; lnk; lnk = lnk->next)
 		while (1) {
 		    size = read(lnk->in,buffer,ATM_MAX_AAL5_PDU);
-		    if (size < 0)
+		    if (size < 0) {
 			if (errno == EAGAIN) break;
 			else {
 			    perror("read");
 			    exit(1);
 			}
+		    }
 		    if (size > 0) {
 			if (!(p = malloc(sizeof(PACKET)-1+size))) {
 			    perror("malloc");
