@@ -1,6 +1,6 @@
 /* policy.c - Access control policies */
  
-/* Written 1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1997,1998 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <atm.h>
@@ -38,7 +38,8 @@ int allow(const struct sockaddr_atmsvc *addr,int direction)
     for (rule = rules; rule; rule = rule->next) {
 	count++;
 	if (!(rule->type & direction)) continue;
-	if (!atm_equal(addr,&rule->addr,rule->mask,AXE_PRVOPT |
+	if (!atm_equal((struct sockaddr *) addr,
+	  (struct sockaddr *) &rule->addr,rule->mask,AXE_PRVOPT |
 	  (rule->mask == -1 ? 0 : AXE_WILDCARD))) continue;
 	rule->hits++;
 	if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,(struct sockaddr *) addr,
